@@ -32,46 +32,22 @@ from sciproc import arraysel
 # So the function will be applied 4x2 times. Each time, the 3 elements along second axis are
 # all passed to the function. The size of the output matrix depends on the function.
 def multifunc(data,axisref,deffunc):
-    SEL = list(repeat(None,len(shape(data))))
-    sizeout = list(repeat(None,len(shape(data))))
-    #before calculating the dataout matrix, its dimension has to be acquired
-    for dim in range(len(shape(data))):
-        if (axisref[dim] == True):
-            SEL[dim] = range(size(data,axis=dim))
-        else:
-            SEL[dim] = [0] 
-            sizeout[dim] = size(data,axis=dim)
-    # print(SEL)
-    # print(data.shape)
-    dummydataout = deffunc(data[arraysel(SEL,data.shape)])
-    dimout = 0
-    for dim in range(len(shape(data))):
-        if (axisref[dim] == True):
-            sizeout[dim] = size(dummydataout,axis=dimout)
-            dimout = dimout + 1
-    dataout = zeros(sizeout)
     #enige wat we eigenlijk nodig hebben voor scandata is shape(data) en shape(dataout) en dataout
+    dataout = zeros(sizeout(data,axisref,deffunc)[0])
     SEL = list(repeat(None,len(shape(data))))
     SELout = list(repeat(None,len(shape(dataout))))
-    print(SELout)
-    print(dataout.shape)
     scandata(0,axisref,SEL,data,deffunc,SELout,dataout)
     return dataout
 
 # this function is called by multifunc. It iteratates through the necessary dimensions to apply a function
 def scandata(dimidx,axisref,SEL,data,deffunc,SELout,dataout):
     # we lopen elk element van een as af
-    print('dimidx',dimidx,' BEGIN')
-    # print(size(data,axis=dimidx))
     axidx = 0
     while (((axisref[dimidx] == True) & (axidx == 0)) | \
             ((axisref[dimidx] == False) & (axidx < size(data,axis=dimidx)) )):
         if (axisref[dimidx] == False):
             SELout[dimidx] = [axidx]
             SEL[dimidx] = [axidx]
-            # print('axidx',axidx)
-            # print('sizeaxidx',size(data,axis=dimidx))
-            # print(((axisref[dimidx] == True) & axidx < size(data,axis=dimidx) ))
         else:
             SELout[dimidx] = range(size(dataout,axis=dimidx))
             SEL[dimidx] = range(size(data,axis=dimidx))
@@ -79,17 +55,13 @@ def scandata(dimidx,axisref,SEL,data,deffunc,SELout,dataout):
         if (dimidx < (len(shape(data)) - 1)):
             scandata(dimidx + 1,axisref,SEL,data,deffunc,SELout,dataout)
         else:
-            # print(SELout)
-            # print(dataout.shape)
-            # print(SEL)
-            # print(data.shape)
-            dataout[arraysel(SELout,dataout.shape)] = deffunc(data[arraysel(SEL,data.shape)])
+            dtemp= deffunc(data[arraysel(SEL,data.shape)])
+            if type(dtemp).__name__ == 'list':
+                dataout[arraysel(SELout,dataout.shape)] = dtemp[0]
+            else:
+                dataout[arraysel(SELout,dataout.shape)] = dtemp
 
-        print('axidx',axidx)
-        print('SEL',SEL)
-        print('SELout',SELout)
         axidx = axidx + 1
-    print('dimidx',dimidx,' END')
 
 # reduce dimension of a multidimensional matrix
 # input: 
@@ -106,6 +78,45 @@ def reddim(data,indices,el = 0):
     return data[arraysel(SEL,shape(data))]
 
 
+def sizeout(data,axisref,deffunc):
+    SEL = list(repeat(None,len(shape(data))))
+    sizeout = list(repeat(None,len(shape(data))))
+    #before calculating the dataout matrix, its dimension has to be acquired
+    for dim in range(len(shape(data))):
+        if (axisref[dim] == True):
+            SEL[dim] = range(size(data,axis=dim))
+        else:
+            SEL[dim] = [0] 
+            sizeout[dim] = size(data,axis=dim)
+    # print(SEL)
+    # print(data.shape)
+
+    # the first item in this list contains dummy data which will not be used; 
+    # the other items potentially contain the output coordinates if available
+    dummydataout = deffunc(data[arraysel(SEL,data.shape)])
+    dimout = 0
+    for dim in range(len(shape(data))):
+        if (axisref[dim] == True):
+            # if list, get the output data size which is given by the first item in the list
+            # if not list (no output coordinates given), just get the size of the data
+            if type(dummydataout).__name__ == 'list':
+                sizeout[dim] = size(dummydataout[0],axis=dimout)
+            else:
+                sizeout[dim] = size(dummydataout,axis=dimout)
+            dimout = dimout + 1
+
+    # shapedataout = sizeout(ncin.variables[evariable][:],\
+    #                        axisref, \
+    #                        lambda data: deffunc(data) )
+    # get the output coordinates of the processed dimensions and save it as a seperate list
+    if type(dummydataout).__name__ == 'list':
+        outcoords = dummydataout[1] 
+    else:
+        outcoords = None
+    return sizeout, outcoords
+
+
+
 # # reduce multiple dimensions at ones
 # # indices: list of indices
 # # data: the multi-dim matrix we want to reduce
