@@ -35,19 +35,20 @@ def cosel(coords = None, outcoords = None, crop=False):
     return selout
 
 # someone may want to do this (if it's possible) instead of interpolation
-def datacosel(indata, cosel = None, coords = None, outcoords = None, \
+def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
               start= None,end= None,step = None,  \
               outstart = None, outend = None, outstep = None, \
               crop = False):
-    if (cosel == None):
+    if (cocosel == None):
         # if coordinates not given, make it from the start, end, step arguments
         if (coords == None):
             coords = dtrange(start, end, step)
         if (outcoords == None):
-            outcoords = dtrange(outstart, outend, outstep)
-        if (outcoords == None):
-            outcoords = coords
-        cosel = cosel(coords = coords, outcoords = outcoords)
+            if ((outstart != None) & (outend != None) & (outstep != None)):
+                outcoords = dtrange(outstart, outend, outstep)
+            else:
+                outcoords = coords
+        cocosel = cosel(coords = coords, outcoords = outcoords)
 
     # remove NA (None) values if specified
     # would be more elegant if we could simply do cosel = cosel[cosel!=None], but None inside [] does strange things
@@ -56,13 +57,13 @@ def datacosel(indata, cosel = None, coords = None, outcoords = None, \
         for ecosel in cosel:
             if (ecosel != None):
                 tempcosel.append(ecosel)
-        cosel = array(tempcosel)
+        cocosel = array(tempcosel)
 
-    dataout = tile(None,len(cosel))
+    dataout = tile(None,len(cocosel))
     #dataout = indata[cosel[cosel!=None]]
     #dataout[cosel==None] = nan
     #dataout[cosel!=None] = indata[cosel[cosel!=None]]
-    for iel, el in enumerate(cosel):
+    for iel, el in enumerate(cocosel):
         if (el != None):
             dataout[iel] = indata[el]
         else:
